Updaters
========

.. automodule:: stonesoup.updater
    :no-members:

.. automodule:: stonesoup.updater.base
    :show-inheritance:

Kalman
------

.. automodule:: stonesoup.updater.kalman
    :show-inheritance:

Particle
--------

.. automodule:: stonesoup.updater.particle
    :show-inheritance:
